@@ -2,9 +2,11 @@ from IoTuring.ClassManager.ClassManager import ClassManager
 from IoTuring.ClassManager import consts
 from IoTuring.Entity.Entity import Entity
 
-class EntityClassManager(ClassManager): # Class to load Entities from the Entitties dir and get them from name 
+
+# Class to load Entities from the Entitties dir and get them from name
+class EntityClassManager(ClassManager):
     def __init__(self):
         ClassManager.__init__(self)
         self.baseClass = Entity
-        self.GetModulesFilename(consts.ENTITIES_PATH) 
-        # self.GetModulesFilename(consts.CUSTOM_ENTITIES_PATH) # TODO Decide if I'll use customs
\ No newline at end of file
+        self.GetModulesFilename(consts.ENTITIES_PATH)
+        # self.GetModulesFilename(consts.CUSTOM_ENTITIES_PATH) # TODO Decide if I'll use customs
