@@ -1,14 +1,17 @@
 from threading import Thread
-
+from IoTuring.Logger.LogObject import LogObject
 # Singleton pattern used
-class EntityManager():
+
+
+class EntityManager(LogObject):
 
     __instance = None
 
     def __init__(self) -> None:
         # Prepare the singleton
         if EntityManager.__instance != None:
-            raise Exception("This class is a singleton, use .getInstance() to access it!")
+            raise Exception(
+                "This class is a singleton, use .getInstance() to access it!")
         else:
             EntityManager.__instance = self
 
@@ -19,15 +22,15 @@ class EntityManager():
         self.passiveEntities = []
 
     @staticmethod
-    def EntityNameToClass(name): # TODO Implement
+    def EntityNameToClass(name):  # TODO Implement
         """ Get entity name and return its class """
         raise NotImplementedError()
 
-    def AddActiveEntity(self, entity): 
+    def AddActiveEntity(self, entity):
         """ Pass an entity instance, add to list of active entities """
         self.activeEntities.append(entity)
 
-    def AddPassiveEntity(self, entity): 
+    def AddPassiveEntity(self, entity):
         """ Pass an entity instance, add to list of passive entities """
         self.passiveEntities.append(entity)
 
@@ -47,31 +50,45 @@ class EntityManager():
         else:
             return self.activeEntities + self.passiveEntities
 
+    def UnloadEntity(self, entity):
+        """ Unloads the passed entity """
+        if entity in self.activeEntities:
+            self.activeEntities.remove(entity)
+        elif entity in self.passiveEntities:
+            self.passiveEntities.remove(entity)
+        else:
+            raise Exception("Can't unload the requested entity: not found among loaded entities.")
+        self.Log(self.LOG_INFO, entity.GetEntityId() + " unloaded")
+
     def InitializeEntities(self):
         for entity in self.GetEntities(includePassive=True):
-            entity.CallInitialize()
+            if not entity.CallInitialize():
+                self.UnloadEntity(entity) # if errors, unload
 
     def PostInitializeEntities(self):
         for entity in self.GetEntities(includePassive=True):
-            entity.CallPostInitialize()
+            if not entity.CallPostInitialize():
+                self.UnloadEntity(entity) # if errors, unload
 
-    def ManageUpdates(self): 
+    def ManageUpdates(self):
         """ Start a thread for each entity in which it will update periodically """
         for entity in self.GetEntities(includePassive=True):
-            Thread(target=entity.LoopThread).start()
-        
+            thread = Thread(target=entity.LoopThread)
+            thread.daemon = True
+            thread.start()
 
     def GetDependentEntitySensorValue(self, callerEntity, entityToFind: str, dataKeyToFind: str):
         """ Called by "callerEntity", return the value of "entityToFind"."dataKeyToFind" if it has value and if the callerEntity has the permission to access that entity.
             Permission is granted if "entityToFind" is present in "callerEntity".GetDependenciesList() """
-        if entityToFind in callerEntity.GetDependenciesList(): # The entity to find must be in the list of entities that the caller entity (the one that wants the other entity) asked in the dependencies
+        if entityToFind in callerEntity.GetDependenciesList():  # The entity to find must be in the list of entities that the caller entity (the one that wants the other entity) asked in the dependencies
             for entity in self.GetEntities(includePassive=True):
                 if entity.GetEntityName() == entityToFind:
                     if not entity.GetEntitySensorByKey(dataKeyToFind).HasValue():
-                        raise Exception("The Entity sensor you asked for hasn't got a value")
-                    return entity.GetEntitySensorByKey(dataKeyToFind).GetValue() # I don't return the entity or the entitydata, because I don't want any edit from outside its entity !
+                        raise Exception(
+                            "The Entity sensor you asked for hasn't got a value")
+                    # I don't return the entity or the entitydata, because I don't want any edit from outside its entity !
+                    return entity.GetEntitySensorByKey(dataKeyToFind).GetValue()
 
-    
     def CheckEntityDependenciesSatisfied(self, callerEntity) -> list:
         """ Returns all the Entities specified in an entity dependencies list that have not been initialized,
             which means they could have been not activated from the configuration or not working correctly """
@@ -82,8 +99,8 @@ class EntityManager():
                     not_found_deps.remove(dependency)
         return not_found_deps
 
-
     # Singleton method
+
     @staticmethod
     def getInstance():
         """ Static access method. """
